searchData={"items":[{"type":"module","title":"UUIDv7","doc":"A UUID v7 implementation and `Ecto.Type` for Elixir.\n\nThe RFC for the version 7 UUID: [RFC 9562](https://datatracker.ietf.org/doc/rfc9562/).\n\nThis library includes an `Ecto.Type` to (auto-)generate version 7 UUIDs in `Ecto.Schema` and beyond.","ref":"UUIDv7.html"},{"type":"module","title":"Installation - UUIDv7","doc":"The package can be installed by adding `uuidv7` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [{:uuidv7, \"~> 1.0\"}]\nend\n```","ref":"UUIDv7.html#module-installation"},{"type":"module","title":"Usage - UUIDv7","doc":"In your database schema, change primary key attribute from `:binary_id` to `UUIDv7`:\n\n```elixir\ndef MyApp.Schemas.User do\n  @primary_key {:id, UUIDv7, autogenerate: true}\nend\n```","ref":"UUIDv7.html#module-usage"},{"type":"function","title":"UUIDv7.bingenerate/0","doc":"Generates a version 7 UUID in the binary format.","ref":"UUIDv7.html#bingenerate/0"},{"type":"function","title":"UUIDv7.bingenerate/1","doc":"Generates a version 7 UUID in the binary format based on the timestamp (ms).","ref":"UUIDv7.html#bingenerate/1"},{"type":"function","title":"UUIDv7.cast/1","doc":"","ref":"UUIDv7.html#cast/1"},{"type":"function","title":"UUIDv7.cast!/1","doc":"","ref":"UUIDv7.html#cast!/1"},{"type":"function","title":"UUIDv7.dump/1","doc":"","ref":"UUIDv7.html#dump/1"},{"type":"function","title":"UUIDv7.dump!/1","doc":"","ref":"UUIDv7.html#dump!/1"},{"type":"function","title":"UUIDv7.embed_as/1","doc":"","ref":"UUIDv7.html#embed_as/1"},{"type":"function","title":"UUIDv7.equal?/2","doc":"","ref":"UUIDv7.html#equal?/2"},{"type":"function","title":"UUIDv7.generate/0","doc":"Generates a version 7 UUID.","ref":"UUIDv7.html#generate/0"},{"type":"function","title":"UUIDv7.generate/1","doc":"Generates a version 7 UUID based on the timestamp (ms).","ref":"UUIDv7.html#generate/1"},{"type":"function","title":"UUIDv7.load/1","doc":"","ref":"UUIDv7.html#load/1"},{"type":"function","title":"UUIDv7.load!/1","doc":"","ref":"UUIDv7.html#load!/1"},{"type":"function","title":"UUIDv7.timestamp/1","doc":"Extracts the timestamp (ms) from the version 7 UUID.","ref":"UUIDv7.html#timestamp/1"},{"type":"type","title":"UUIDv7.raw/0","doc":"A raw binary representation of a UUID.","ref":"UUIDv7.html#t:raw/0"},{"type":"type","title":"UUIDv7.t/0","doc":"A hex-encoded UUID string.","ref":"UUIDv7.html#t:t/0"},{"type":"extras","title":"UUIDv7","doc":"# UUIDv7\n\n[![CI](https://github.com/martinthenth/uuidv7/actions/workflows/elixir.yml/badge.svg)](https://github.com/martinthenth/uuidv7/actions/workflows/elixir.yml)\n[![Hex.pm](https://img.shields.io/hexpm/v/uuidv7)](https://hex.pm/packages/uuidv7)\n[![Hex.pm](https://img.shields.io/hexpm/dt/uuidv7)](https://hex.pm/packages/uuidv7)\n[![Hex.pm](https://img.shields.io/hexpm/l/uuidv7)](https://github.com/martinthenth/uuidv7/blob/main/LICENSE)\n\nA UUID v7 implementation and `Ecto.Type` for Elixir.\n\nThe RFC for the version 7 UUID: [RFC 9562](https://datatracker.ietf.org/doc/rfc9562/).\n\nThis library includes an `Ecto.Type` to (auto-)generate version 7 UUIDs in `Ecto.Schema` and beyond.","ref":"readme.html"},{"type":"extras","title":"Installation - UUIDv7","doc":"The package can be installed by adding `uuidv7` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [{:uuidv7, \"~> 1.0\"}]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - UUIDv7","doc":"In your database schema, change primary key attribute from `:binary_id` to `UUIDv7`:\n\n```elixir\ndef App.Schemas.User do\n  @primary_key {:id, UUIDv7, autogenerate: true}\nend\n```","ref":"readme.html#usage"},{"type":"extras","title":"Benchmark - UUIDv7","doc":"Run `mix deps.get` and then `mix run scripts/bench.exs` to run the benchmark on your computer.\n\n```zsh\nOperating System: macOS\nCPU Information: Apple M2 Pro\nNumber of Available Cores: 10\nAvailable memory: 16 GB\nElixir 1.17.2\nErlang 27.0.1\nJIT enabled: true\n\nBenchmark suite executing with the following configuration:\nwarmup: 5 s\ntime: 10 s\nmemory time: 5 s\nreduction time: 0 ns\nparallel: 1\ninputs: none specified\nEstimated total run time: 1 min\n\nName                     ips        average  deviation         median         99th %\nuuidv7                1.82 M      550.49 ns ±15102.40%         417 ns        1291 ns\nuniq (uuid v7)        1.80 M      554.54 ns ±19362.74%         417 ns        1292 ns\necto (uuid v4)        1.72 M      579.75 ns ±12640.39%         458 ns        1208 ns\n\nComparison:\nuuidv7                1.82 M\nuniq (uuid v7)        1.80 M - 1.01x slower +4.05 ns\necto (uuid v4)        1.72 M - 1.05x slower +29.25 ns\n\nMemory usage statistics:\n\nName                   average  deviation         median         99th %\nuuidv7                237.99 B     ±2.23%          240 B          240 B\nuniq (uuid v7)        214.01 B     ±2.47%          216 B          216 B\necto (uuid v4)        214.01 B     ±2.47%          216 B          216 B\n\nComparison:\nuuidv7                   240 B\nuniq (uuid v7)        214.01 B - 0.90x memory usage -23.98508 B\necto (uuid v4)        214.01 B - 0.90x memory usage -23.98596 B\n```","ref":"readme.html#benchmark"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}